
# Loren Williams, Georgia Tech
# pymol script for looking at the BACILLUS DNA POLYMERASE I FRAGMENT
# and DNA fragments
# stepwise DNA replication

# From Visualizing DNA replication in a catalytically active Bacillus DNA polymerase crystal
# James R. Kiefer, Chen Mao, Jeffrey C. Braman & Lorena S. Beese


## Header: General Commands ##
# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 1
## End of Header: General Commands ##

load files/1L3S.pdb, Complex_A
load files/1L3T.pdb, Complex_B
load files/1L3U.pdb, Complex_C
# load files/1L3V.pdb, Complex_D
load files/1L5U.pdb, Complex_E
#load 1LV5.pdb, Complex_F

create DNA_A, Complex_A and Chain B+C 
create DNA_B, Complex_B and Chain B+C 
create DNA_C, Complex_C and Chain B+C 
# create DNA_D, Complex_D and Chain B+C 
create DNA_E, Complex_E and Chain B+C 
#create DNA_F, Complex_F and Chain C+D+E+F 



#-------- carton DNA
set cartoon_ring_mode=2, DNA_*
hide everything, DNA_*
set cartoon_tube_radius=0.4, DNA_*
show cartoon, DNA_*
show stick, DNA_*

color wheat, DNA_A and resn DA and name C* and resi 5
color wheat, DNA_B and resn DA and name C* and resi 4
color wheat, DNA_C and resn DA and name C* and resi 5
color wheat, DNA_E and resn DA and name C* and resi 6
remove resn HOH and DNA_*



create Protein_A, Complex_A and Chain A
create Protein_B, Complex_B and Chain A
create Protein_C, Complex_C and Chain A
# create Protein_D, Complex_D and Chain A
create Protein_E, Complex_E and Chain A
#create Protein_F, Complex_F and Chain A

#-------- Cartoon Protein_*
hide everything, Protein_*
show cartoon, Protein_*
color blue, Protein_*
color cyan, ss h and Protein_*
color magenta, ss s and Protein_*

#---------------hydrogen bonds----------------

distance WC_Hbond, (name O2,N3,N4 and resn DC and DNA_A_stick ), (name N2,N1,O6 and resn DG and DNA_A_stick ), 3.27
distance WC_Hbond, (name N3,O4 and resn DT and DNA_A_stick ), (name N1,N6 and resn DA and DNA_A_stick ), 3.27
color black, WC_Hbond
hide labels, WC_Hbond
set dash_width, 3
set dash_gap, 0.4


#---------------create metal site----------------

create Metal_Complex, /Complex_A//A/MG`920/MG + /Complex_A//A/TYR`654/* + /Complex_A//A/ASP`830/ +  /Complex_A//A/ASP`653/ +  /Complex_A//A/HOH`2525/O 

hide everything, Metal_Complex 
show sticks, Metal_Complex
show nb_spheres, /Metal_Complex//A/MG`920/MG
show nb_spheres, /Metal_Complex//A/HOH`2525/O 
color yellow, Metal_Complex and resi 920
distance Mg_coordination, (name Mg and Metal_Complex ), (Metal_Complex and not name Mg), 3.27

#---------------create protein-DNA interface----------------

create interface, byres(Protein_A within 4 of DNA_A)
remove (interface within .1 of DNA_A)
color red, name O* and interface
color cyan, name C* and interface
color blue, name N* and interface
color yellow, name P* and interface
color yellow, name S* and interface
hide everything, interface
show spheres, interface
remove resn hoh and interface


delete Complex_*

disable all
enable DNA_A
enable Protein_A
enable Metal_Complex
enable WC_Hbond
enable Mg_coordination

set_view (\
     0.684823334,   -0.644832611,    0.339449733,\
     0.715259016,    0.505662501,   -0.482413471,\
     0.139425963,    0.573157132,    0.807507277,\
     0.000503734,    0.000216219, -123.906066895,\
    12.423979759,   35.446918488,   27.943511963,\
    68.897338867,  178.935409546,    0.000000000 )
### cut above here and paste into script ### 
#ray